@@ -38,6 +38,7 @@ class WorkflowInstance:
         self.workflow_context_id = None
         self.workflow_context_name = None
         self.workflow_definition_id = None
+        self.xml_response = None
 
     def __str__(self):
         return f"Workflow Instance ID: {self.instance_id}"
@@ -86,7 +87,7 @@ class WorkflowAPI(AuthenticatedAPI):
                        'Failed']
     workflow_types = ['Ingest', 'Access', 'Transformation', 'DataManagement']
 
-    def __init__(self, username: str = None, password: str = None, tenant: str = "%", server: str = None,
+    def __init__(self, username: str = None, password: str = None, tenant: str = None, server: str = None,
                  use_shared_secret: bool = False):
         super().__init__(username, password, tenant, server, use_shared_secret)
         self.base_url = "sdb/rest/workflow"
@@ -238,8 +239,9 @@ class WorkflowAPI(AuthenticatedAPI):
 
         """
         headers = {HEADER_TOKEN: self.token}
+        params = {"includeErrors": "true"}
         request = self.session.get(f'https://{self.server}/{self.base_url}/instances/{str(instance_id)}',
-                                   headers=headers)
+                                   headers=headers, params=params)
         if request.status_code == requests.codes.ok:
             xml_response = str(request.content.decode('utf-8'))
             logger.debug(xml_response)
@@ -269,6 +271,8 @@ class WorkflowAPI(AuthenticatedAPI):
             workflow_instance.workflow_definition_id = entity_response.find(
                 f".//{{{NS_WORKFLOW}}}WorkflowDefinitionTextId").text
 
+            workflow_instance.xml_response = xml_response
+
             return workflow_instance
         elif request.status_code == requests.codes.unauthorized:
             self.token = self.__token__()
